@@ -222,7 +222,7 @@ static int parse_code(const char *string)
 }
 
 const char *argp_program_version = "IR keytable control version " V4L_UTILS_VERSION;
-const char *argp_program_bug_address = "Mauro Carvalho Chehab <m.chehab@samsung.com>";
+const char *argp_program_bug_address = "Mauro Carvalho Chehab <mchehab@kernel.org>";
 
 static const char doc[] = N_(
 	"\nAllows get/set IR keycode/scancode tables\n"
