@@ -26,44 +26,44 @@ static double output_fps = 0;		/* set framerate speed, in fps */
 void misc_usage(void)
 {
 	printf("\nMiscellaneous options:\n"
-	       "  --wait-for-event=<event>\n"
+	       "  --wait-for-event <event>\n"
 	       "                     wait for an event [VIDIOC_DQEVENT]\n"
 	       "                     <event> is the event number or one of:\n"
 	       "                     eos, vsync, ctrl=<id>, frame_sync, source_change=<pad>,\n"
 	       "                     motion_det\n"
 	       "                     where <id> is the name of the control\n"
 	       "                     and where <pad> is the index of the pad or input\n"
-	       "  --poll-for-event=<event>\n"
+	       "  --poll-for-event <event>\n"
 	       "                     poll for an event [VIDIOC_DQEVENT]\n"
 	       "                     see --wait-for-event for possible events\n"
 	       "  -P, --get-parm     display video parameters [VIDIOC_G_PARM]\n"
-	       "  -p, --set-parm=<fps>\n"
+	       "  -p, --set-parm <fps>\n"
 	       "                     set video framerate in <fps> [VIDIOC_S_PARM]\n"
 	       "  --get-output-parm  display output video parameters [VIDIOC_G_PARM]\n"
-	       "  --set-output-parm=<fps>\n"
+	       "  --set-output-parm <fps>\n"
 	       "                     set output video framerate in <fps> [VIDIOC_S_PARM]\n"
 	       "  --get-jpeg-comp    query the JPEG compression [VIDIOC_G_JPEGCOMP]\n"
-	       "  --set-jpeg-comp=quality=<q>,markers=<markers>,comment=<c>,app<n>=<a>\n"
+	       "  --set-jpeg-comp quality=<q>,markers=<markers>,comment=<c>,app<n>=<a>\n"
 	       "                     set the JPEG compression [VIDIOC_S_JPEGCOMP]\n"
 	       "                     <n> is the app segment: 0-9/a-f, <a> is the actual string.\n"
 	       "                     <markers> is a colon separated list of:\n"
 	       "                     dht:      Define Huffman Tables\n"
 	       "                     dqt:      Define Quantization Tables\n"
 	       "                     dri:      Define Restart Interval\n"
-	       "  --encoder-cmd=cmd=<cmd>,flags=<flags>\n"
+	       "  --encoder-cmd cmd=<cmd>,flags=<flags>\n"
 	       "                     Send a command to the encoder [VIDIOC_ENCODER_CMD]\n"
 	       "                     cmd=start|stop|pause|resume\n"
 	       "                     flags=stop_at_gop_end\n"
-	       "  --try-encoder-cmd=cmd=<cmd>,flags=<flags>\n"
+	       "  --try-encoder-cmd cmd=<cmd>,flags=<flags>\n"
 	       "                     Try an encoder command [VIDIOC_TRY_ENCODER_CMD]\n"
 	       "                     See --encoder-cmd for the arguments.\n"
-	       "  --decoder-cmd=cmd=<cmd>,flags=<flags>,stop_pts=<pts>,start_speed=<speed>,\n"
+	       "  --decoder-cmd cmd=<cmd>,flags=<flags>,stop_pts=<pts>,start_speed=<speed>,\n"
 	       "                     start_format=<none|gop>\n"
 	       "                     Send a command to the decoder [VIDIOC_DECODER_CMD]\n"
 	       "                     cmd=start|stop|pause|resume\n"
 	       "                     flags=start_mute_audio|pause_to_black|stop_to_black|\n"
 	       "                           stop_immediately\n"
-	       "  --try-decoder-cmd=cmd=<cmd>,flags=<flags>\n"
+	       "  --try-decoder-cmd cmd=<cmd>,flags=<flags>\n"
 	       "                     Try a decoder command [VIDIOC_TRY_DECODER_CMD]\n"
 	       "                     See --decoder-cmd for the arguments.\n"
 	       );
@@ -308,8 +308,10 @@ void misc_cmd(int ch, char *optarg)
 	}
 }
 
-void misc_set(int fd)
+void misc_set(cv4l_fd &_fd)
 {
+	int fd = _fd.g_fd();
+
 	if (options[OptSetParm]) {
 		memset(&parm, 0, sizeof(parm));
 		parm.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
@@ -362,8 +364,10 @@ void misc_set(int fd)
 			print_deccmd(dec_cmd);
 }
 
-void misc_get(int fd)
+void misc_get(cv4l_fd &_fd)
 {
+	int fd = _fd.g_fd();
+
 	if (options[OptGetJpegComp]) {
 		struct v4l2_jpegcompression jc;
 		if (doioctl(fd, VIDIOC_G_JPEGCOMP, &jc) == 0)
